=== modified file 'NEWS'
--- NEWS	2007-01-30 11:52:30 +0000
+++ NEWS	2007-02-01 13:33:45 +0000
@@ -30,6 +30,11 @@
       push, pull, commit, and so on. Developed for use with the branchrss
       plugin. See bzrlib.branch.BranchHooks for more details. (Robert Collins)
 
+    * New Branch.last_revision_info method, this is being done to allow
+      optimization of requests for both the number of revisions and the last
+      revision of a branch with smartservers and potentially future branch
+      formats. (Wouter van Heyst, Robert Collins)
+
   BUGFIXES:
 
   TESTING:

=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2007-01-30 11:52:30 +0000
+++ bzrlib/branch.py	2007-02-01 13:33:45 +0000
@@ -324,6 +324,18 @@
         else:
             return None
 
+    def last_revision_info(self):
+        """Return information about the last revision.
+
+        :return: A tuple (revno, last_revision_id).
+        """
+        rh = self.revision_history()
+        revno = len(rh)
+        if revno:
+            return (revno, rh[-1])
+        else:
+            return (0, _mod_revision.NULL_REVISION)
+
     def missing_revisions(self, other, stop_revision=None):
         """Return a list of new revisions that would perfectly fit.
         

=== modified file 'bzrlib/tests/branch_implementations/__init__.py'
--- bzrlib/tests/branch_implementations/__init__.py	2007-01-29 16:58:49 +0000
+++ bzrlib/tests/branch_implementations/__init__.py	2007-02-01 13:33:45 +0000
@@ -44,6 +44,7 @@
         'bzrlib.tests.branch_implementations.test_break_lock',
         'bzrlib.tests.branch_implementations.test_hooks',
         'bzrlib.tests.branch_implementations.test_http',
+        'bzrlib.tests.branch_implementations.test_last_revision_info',
         'bzrlib.tests.branch_implementations.test_locking',
         'bzrlib.tests.branch_implementations.test_parent',
         'bzrlib.tests.branch_implementations.test_permissions',

=== added file 'bzrlib/tests/branch_implementations/test_last_revision_info.py'
--- bzrlib/tests/branch_implementations/test_last_revision_info.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/branch_implementations/test_last_revision_info.py	2007-02-01 13:33:45 +0000
@@ -0,0 +1,35 @@
+# Copyright (C) 2004, 2005, 2007 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Tests for branch.last_revision_info."""
+
+from bzrlib.revision import NULL_REVISION
+from bzrlib.tests import TestCaseWithTransport
+
+
+class TestLastRevisionInfo(TestCaseWithTransport):
+
+    def test_empty_branch(self):
+        # on an empty branch we want (0, NULL_REVISION)
+        branch = self.make_branch('branch')
+        self.assertEqual((0, NULL_REVISION), branch.last_revision_info())
+    
+    def test_non_empty_branch(self):
+        # after the second commit we want (2, 'second-revid')
+        tree = self.make_branch_and_tree('branch')
+        tree.commit('1st post')
+        revid = tree.commit('2st post', allow_pointless=True)
+        self.assertEqual((2, revid), tree.branch.last_revision_info())

